@@ -15,13 +15,20 @@
 # Copyright (C) 2014 Fracpete (fracpete at gmail dot com)
 
 import javabridge
-import matplotlib.pyplot as plt
+import logging
+import weka.plot as plot
+if plot.matplotlib_available:
+    import matplotlib.pyplot as plt
 from weka.core.classes import JavaObject
 from weka.core.dataset import Instances
 from weka.classifiers import NumericPrediction, NominalPrediction
 
+# logging setup
+logger = logging.getLogger(__name__)
 
-def plot_classifier_errors(predictions, absolute=True, max_relative_size=50, absolute_size=50, outfile=None, wait=True):
+
+def plot_classifier_errors(predictions, absolute=True, max_relative_size=50, absolute_size=50, title=None,
+                           outfile=None, wait=True):
     """
     Plots the classifers for the given list of predictions.
     TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
@@ -33,11 +40,16 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=50, abs
     :type max_relative_size: int
     :param absolute_size: the size in point in case of absolute mode
     :type absolute_size: int
+    :param title: an optional title
+    :type title: str
     :param outfile: the output file, ignored if None
     :type outfile: str
     :param wait: whether to wait for the user to close the plot
     :type wait: bool
     """
+    if not plot.matplotlib_available:
+        logger.error("Matplotlib is not installed, plotting unavailable!")
+        return
     actual = []
     predicted = []
     error = None
@@ -71,9 +83,12 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=50, abs
         ax.scatter(actual, predicted, s=error, alpha=0.5)
     ax.set_xlabel("actual")
     ax.set_ylabel("predicted")
-    ax.set_title("Classifier errors")
+    if title is None:
+        title = "Classifier errors"
+    ax.set_title(title)
     ax.plot(ax.get_xlim(), ax.get_ylim(), ls="--", c="0.3")
     ax.grid(True)
+    fig.canvas.set_window_title(title)
     plt.draw()
     if not outfile is None:
         plt.savefig(outfile)
@@ -122,7 +137,7 @@ def get_thresholdcurve_data(data, xname, yname):
     return x, y
 
 
-def plot_roc(evaluation, class_index=0, outfile=None, wait=True):
+def plot_roc(evaluation, class_index=0, title=None, outfile=None, wait=True):
     """
     Plots the ROC (receiver operator characteristics) curve for the given predictions.
     TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
@@ -130,11 +145,16 @@ def plot_roc(evaluation, class_index=0, outfile=None, wait=True):
     :type evaluation: Evaluation
     :param class_index: the 0-based index of the class-label to create the plot for
     :type class_index: int
+    :param title: an optional title
+    :type title: str
     :param outfile: the output file, ignored if None
     :type outfile: str
     :param wait: whether to wait for the user to close the plot
     :type wait: bool
     """
+    if not plot.matplotlib_available:
+        logger.error("Matplotlib is not installed, plotting unavailable!")
+        return
     data = generate_thresholdcurve_data(evaluation, class_index)
     area = javabridge.static_call(
         "weka/classifiers/evaluation/ThresholdCurve", "getROCArea", "(Lweka/core/Instances;)D", data.jobject)
@@ -143,9 +163,13 @@ def plot_roc(evaluation, class_index=0, outfile=None, wait=True):
     ax.plot(x, y)
     ax.set_xlabel("False Positive Rate")
     ax.set_ylabel("True Positive Rate")
-    ax.set_title("ROC (%0.4f)" % area)
+    if title is None:
+        title = "ROC"
+    title += " (%0.4f)" % area
+    ax.set_title(title)
     ax.plot(ax.get_xlim(), ax.get_ylim(), ls="--", c="0.3")
     ax.grid(True)
+    fig.canvas.set_window_title(title)
     plt.xlim([-0.05, 1.05])
     plt.ylim([-0.05, 1.05])
     plt.draw()
@@ -155,7 +179,7 @@ def plot_roc(evaluation, class_index=0, outfile=None, wait=True):
         plt.show()
 
 
-def plot_prc(evaluation, class_index=0, outfile=None, wait=True):
+def plot_prc(evaluation, class_index=0, title=None, outfile=None, wait=True):
     """
     Plots the PRC (precision recall) curve for the given predictions.
     TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
@@ -163,20 +187,28 @@ def plot_prc(evaluation, class_index=0, outfile=None, wait=True):
     :type evaluation: Evaluation
     :param class_index: the 0-based index of the class-label to create the plot for
     :type class_index: int
+    :param title: an optional title
+    :type title: str
     :param outfile: the output file, ignored if None
     :type outfile: str
     :param wait: whether to wait for the user to close the plot
     :type wait: bool
     """
+    if not plot.matplotlib_available:
+        logger.error("Matplotlib is not installed, plotting unavailable!")
+        return
     data = generate_thresholdcurve_data(evaluation, class_index)
     x, y = get_thresholdcurve_data(data, "Recall", "Precision")
     fig, ax = plt.subplots()
     ax.plot(x, y)
     ax.set_xlabel("Recall")
     ax.set_ylabel("Precision")
-    ax.set_title("PRC")
+    if title is None:
+        title = "PRC"
+    ax.set_title(title)
     ax.plot(ax.get_xlim(), ax.get_ylim(), ls="--", c="0.3")
     ax.grid(True)
+    fig.canvas.set_window_title(title)
     plt.xlim([-0.05, 1.05])
     plt.ylim([-0.05, 1.05])
     plt.draw()
